<?php
namespace Inti\Gath\Api;

use GuzzleHttp\ClientInterface as HttpClientInterface;
use GuzzleHttp\Exception\GuzzleException;
use RuntimeException;

/**
 * Klijent za pristup Gathovom 'REST' servisu.
 *
 * @package Inti\Gath\Api
 * @author Danijel Fabijan <hipnaba@gmail.com>
 * @link https://bitbucket.org/oktan-nautika/inti-gath-api
 */
class Client implements ClientInterface
{
    /** @var HttpClientInterface */
    private $httpClient;

    /**
     * Konstruktor.
     *
     * @param HttpClientInterface $httpClient
     */
    public function __construct(HttpClientInterface $httpClient)
    {
        $this->httpClient = $httpClient;
    }

    /**
     * @param string $method
     * @param string $path
     * @param array $params
     * @return array
     *
     * @throws GuzzleException
     */
    public function request(string $method, string $path, array $params = []): array
    {
        switch ($method) {
            case 'GET':
                $params = array_map(function ($value) {
                    return is_array($value) ? implode(';', $value) : $value;
                }, $params);
                $request = ['query' => $params];
                break;
            case 'POST':
                $request = ['json' => $params];
                break;
            default:
                throw new RuntimeException('Gath podržava samo GET i POST http metode.');
        }

        $response = $this->httpClient->request($method, $path, $request);
        $json = $response->getBody()->getContents();

        return json_decode($json, true, 512, JSON_THROW_ON_ERROR);
    }
}
