<?php
namespace Inti\Gath\Api\Endpoint;

use Inti\Gath\Api\Query\QueryInterface;
use Inti\Gath\Api\Result\ResultInterface;
use Inti\Gath\Api\ClientInterface;

/**
 * Defaultna implementacija krajnje točke.
 *
 * @package Inti\Gath\Api\Endpoint
 * @author Danijel Fabijan <hipnaba@gmail.com>
 * @link https://bitbucket.org/oktan-nautika/inti-gath
 */
abstract class AbstractEndpoint implements EndpointInterface
{
    /** @var ClientInterface */
    private $client;
    /** @var string */
    protected $method = 'GET';
    /** @var string */
    protected $path = '';
    /** @var string */
    protected $resultClass;

    /**
     * Konstruktor.
     *
     * @param ClientInterface $client
     */
    public function __construct(ClientInterface $client)
    {
        $this->client = $client;
    }

    /**
     * Poziva krajnju točku
     *
     * @param QueryInterface|null $query
     * @return ResultInterface
     */
    public function call(QueryInterface $query = null): ResultInterface
    {
        $resultClass = $this->resultClass;

        $params = $query ? $this->extractParams($query) : [];
        $params = array_filter($params, function ($value) {
            return !is_null($value);
        });

        $resultData = $this->client->request($this->method, $this->path, $params);
        return new $resultClass($resultData);
    }

    /**
     * Pretvara dati upit u array spreman za slanje prema servisu.
     *
     * @param QueryInterface $query
     * @return array
     */
    protected function extractParams(QueryInterface $query): array
    {
        return (array) $query;
    }
}
