<?php
namespace Inti\Gath\Api\Endpoint;

use Inti\Gath\Api\Query\GetProductPriceQuery;
use Inti\Gath\Api\Query\QueryInterface;
use Inti\Gath\Api\Result\GetProductPriceResult;

/**
 * Vraća cijene za date proizvode.
 *
 * @package Inti\Gath\Api\Endpoint
 * @author Danijel Fabijan <hipnaba@gmail.com>
 * @link https://bitbucket.org/oktan-nautika/inti-gath
 *
 * @method GetProductPriceResult call(object $query)
 */
final class GetProductPrice extends AbstractEndpoint
{
    /** @var string */
    protected $method = 'POST';
    /** @var string */
    protected $path = 'prices/by-codes';
    /** @var string */
    protected $resultClass = GetProductPriceResult::class;

    /**
     * @param QueryInterface $query
     * @return array
     */
    protected function extractParams(QueryInterface $query): array
    {
        if (
            !$query instanceof GetProductPriceQuery
            || (!count($query->Codes ?? []) && !count($query->TireIds))
        ) {
            return [];
        }

        return [
            'Codes' => $query->Codes ?? [],
            'TireIds' => $query->TireIds ?? [],
            'PriceRabatePolicy' => $query->PriceRabatePolicy ?? false,
            'Username' => $query->Username,
            'Discount' => true,
        ];
    }
}
