<?php
namespace Inti\Gath\Api\Endpoint;

use Inti\Gath\Api\Query\GetProductStockQuery;
use Inti\Gath\Api\Query\QueryInterface;
use Inti\Gath\Api\Result\GetProductStockResult;

/**
 * Vraća stanja zaliha za date proizvode.
 *
 * @package Inti\Gath\Api\Endpoint
 * @author Danijel Fabijan <hipnaba@gmail.com>
 * @link https://bitbucket.org/oktan-nautika/inti-gath
 *
 * @method GetProductStockResult call(GetProductStockQuery $query)
 */
final class GetProductStock extends AbstractEndpoint
{
    /** @var string */
    protected $method = 'POST';
    /** @var string */
    protected $path = 'stock/by-codes';
    /** @var string */
    protected $resultClass = GetProductStockResult::class;

    /**
     * @param QueryInterface $query
     * @return array
     */
    protected function extractParams(QueryInterface $query): array
    {
        if (
            !$query instanceof GetProductStockQuery
            || (!count($query->Codes ?? []) && !count($query->TireIds ?? []))
        ) {
            return [];
        }

        return [
            'Codes' => $query->Codes ?? null,
            'TireIds' => $query->TireIds ?? null,
            'StockByWarehouses' => $query->StockByWarehouses ?? false,
        ];
    }
}
