<?php
namespace Inti\Gath\Api\Query;

/**
 * Osnovni upit prema Gathu.
 *
 * @package Inti\Gath\Api\Query
 * @author Danijel Fabijan <hipnaba@gmail.com>
 * @link https://bitbucket.org/oktan-nautika/inti-gath-api
 */
abstract class AbstractQuery implements QueryInterface
{
    /** @var array */
    private $query = [];

    /**
     * AbstractQuery constructor.
     * @param array $query
     */
    public function __construct(array $query = [])
    {
        foreach ($query as $name => $value) {
            $this->__set($name, $value);
        }
    }

    /**
     * @param string $name
     * @return mixed|null
     */
    public function __get(string $name)
    {
        $getter = 'get' . ucfirst($name);

        return method_exists($this, $getter)
            ? $this->$getter()
            : ($this->query[$name] ?? null);
    }

    /**
     * @param string $name
     * @param $value
     */
    public function __set(string $name, $value)
    {
        $setter = 'set' . ucfirst($name);

        if (method_exists($this, $setter)) {
            $this->$setter($value);
        } else {
            $this->query[$name] = $value;
        }
    }

    /**
     * @return array
     */
    public function toArray(): array
    {
        return $this->query;
    }
}
