<?php
namespace Inti\Gath\Api\Record;

/**
 * Podaci o cijeni proizvoda.
 *
 * @package Inti\Gath\Api\Record
 * @author Danijel Fabijan <hipnaba@gmail.com>
 * @link https://bitbucket.org/oktan-nautika/inti-gath
 *
 * @property string                             $ProductCode    Šifra proizvoda.
 * @property int                                $ProductId      DataLink proizvoda.
 * @property string                             $Currency       ISO4217 oznaka valute.
 * @property float                              $PriceRetail    Cijena s porezom.
 * @property float                              $PriceWholesale Cijena bez poreza.
 * @property float                              $Refunds        Iznos povratne naknade.
 * @property ProductPriceRabPolicyRecord[]|null $RabPolicy      Cijene iz rabatne politike.
 * @property ProductPriceDiscountRecord[]|null  $Discount       Akcijske cijene.
 * @property bool                               $HidePrice      Da li je cijena ovog proizvoda sakrivena?
 */
final class ProductPriceRecord extends AbstractRecord
{
    /**
     * Konstruktor.
     *
     * @param array $record
     */
    public function __construct(array $record)
    {
        foreach ($record['RabPolicy'] ?? [] as $rabPolicyData) {
            $rabPolicy[] = new ProductPriceRabPolicyRecord($rabPolicyData);
        }

        foreach ($record['Discount'] ?? [] as $discountData) {
            $discount[] = new ProductPriceDiscountRecord($discountData);
        }

        $record['RabPolicy'] = $rabPolicy ?? [];
        $record['Discount'] = $discount ?? [];

        parent::__construct($record);
    }
}
