<?php
namespace IntiTest\Gath\Api\Endpoint;

use GuzzleHttp\Client as HttpClient;
use Inti\Gath\Api\Endpoint\GetProductStock;
use Inti\Gath\Api\Client;
use Inti\Gath\Api\Query\GetProductStockQuery;
use Inti\Gath\Api\Record\ProductStockRecord;
use PHPUnit\Framework\TestCase;

/**
 * Class GetProductStockTest
 *
 * @package IntiTest\Gath\Api\Endpoint
 * @author Danijel Fabijan <hipnaba@gmail.com>
 * @link https://bitbucket.org/oktan-nautika/inti-gath
 */
final class GetProductStockTest extends TestCase
{
    public function testCanGetProductStock()
    {
        $httpClient = new HttpClient([
            'base_uri' => 'http://172.30.60.120:30024/',
            'timeout' => 2,
        ]);

        $client = new Client($httpClient);
        $endpoint = new GetProductStock($client);

        $result = $endpoint->call(new GetProductStockQuery([
            'Codes' => ['PROD01', 'PROD02'],
        ]));

        $this->assertIsArray($result->Results);
        $this->assertCount(2, $result->Results);

        $productStock = $result->Results[0];
        $this->assertInstanceOf(ProductStockRecord::class, $productStock);
        $this->assertEquals('PROD01', $productStock->ProductCode);
        $this->assertEquals(2, $productStock->ProductId);
        $this->assertEquals(0, $productStock->PurchaseStep);
        $this->assertEquals(150, $productStock->Stock);
    }
}
